@@ -6,7 +6,7 @@ package App::PP::Autolink;
 
 use strict;
 use warnings;
-use 5.010;
+use 5.014;
 
 use Carp;
 use English qw / -no_match_vars /;
@@ -24,7 +24,7 @@ use Config;
 use Getopt::ArgvFile default=>1;
 use Getopt::Long qw / GetOptionsFromArray :config pass_through /;
 
-our $VERSION = '2.07';
+our $VERSION = '2.08';
 
 use constant CASE_INSENSITIVE_OS => ($^O eq 'MSWin32');
 
@@ -102,8 +102,9 @@ sub build {
     say 'Detected link list: '   . join ' ', grep {$_ ne '--link'} @links;
     say '';
 
-    my @alien_deps = map {; '-M' => $_} uniq @{$self->{alien_deps}};
-    say 'Detected alien list: '  . join ' ', sort uniq @{$self->{alien_deps}};
+    my @aliens = uniq @{$self->{alien_deps}};
+    my @alien_deps = map {; '-M' => $_} @aliens;
+    say 'Detected aliens: '  . join ' ', sort @aliens;
     say '';
 
     my @command = (
@@ -272,7 +273,7 @@ sub _resolve_rpath_mac {
     my @lc_rpath_chunk;
     while (my $line = shift @results) {
         last if $line =~ /LC_/;  #  any other command
-	push @lc_rpath_chunk, $line;
+	      push @lc_rpath_chunk, $line;
     }
     my @paths
       = map {s/\s\(offset.+$//r}
@@ -287,7 +288,7 @@ sub _resolve_rpath_mac {
         $path = path($path, $target);
         if ($path->exists) {
             $path = $path->realpath->stringify;
-	    push @checked_paths, $path;
+            push @checked_paths, $path;
         }
     }
 
